Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
SrcDir string
PkgName string
Formatter string
StubImpl bool
SkipEnsure bool
WithResets bool
}
Config specifies details about how interfaces should be mocked. SrcDir is the only field which needs be specified.
Click to show internal directories.
Click to hide internal directories.